@@ -2,7 +2,7 @@ use libtaos::*;
 use std::env::var;
 
 pub fn init() {
-    std::env::set_var("RUST_LOG", "trace");
+    std::env::set_var("RUST_LOG", "libtaos=trace");
     env_logger::init();
 }
 
